==> vlc-android-0.1.3.tar.gz: vlc-android/src/org/videolan/vlc/gui/SearchResultAdapter.java <==
/*****************************************************************************
 * SearchResultAdapter.java
 *****************************************************************************
 * Copyright © 2011-2012 VLC authors and VideoLAN
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

package org.videolan.vlc.gui;

import java.util.Comparator;

import org.videolan.vlc.Media;
import org.videolan.vlc.Util;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.TextView;

public class SearchResultAdapter extends ArrayAdapter<Media>
        implements Comparator<Media> {

    public SearchResultAdapter(Context context) {
        super(context, 0);
    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        ViewHolder holder;
        View view = convertView;
        if (view == null) {
            LayoutInflater inflater = (LayoutInflater) getContext().getSystemService(Context.LAYOUT_INFLATER_SERVICE);
            view = inflater.inflate(android.R.layout.simple_list_item_1, parent, false);
            holder = new ViewHolder();
            holder.text = (TextView) view.findViewById(android.R.id.text1);
            view.setTag(holder);
        } else
            holder = (ViewHolder) view.getTag();

        Media item = getItem(position);
        Util.setItemBackground(holder.text, position);
        holder.text.setText(item.getTitle());

        return view;
    }

    @Override
    public int compare(Media object1, Media object2) {
        return object1.getTitle().compareToIgnoreCase(object2.getTitle());
    }

    public void sort() {
        super.sort(this);
    }

    static class ViewHolder {
        TextView text;
    }
}

==> vlc-android-0.9.2.tar.gz: vlc-android/src/org/videolan/vlc/gui/SearchResultAdapter.java <==
/*****************************************************************************
 * SearchResultAdapter.java
 *****************************************************************************
 * Copyright © 2011-2012 VLC authors and VideoLAN
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

package org.videolan.vlc.gui;

import java.util.Comparator;

import org.videolan.libvlc.Media;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.TextView;

public class SearchResultAdapter extends ArrayAdapter<Media>
        implements Comparator<Media> {

    public SearchResultAdapter(Context context) {
        super(context, 0);
    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        ViewHolder holder;
        View view = convertView;
        if (view == null) {
            LayoutInflater inflater = (LayoutInflater) getContext().getSystemService(Context.LAYOUT_INFLATER_SERVICE);
            view = inflater.inflate(android.R.layout.simple_list_item_1, parent, false);
            holder = new ViewHolder();
            holder.text = (TextView) view.findViewById(android.R.id.text1);
            view.setTag(holder);
        } else
            holder = (ViewHolder) view.getTag();

        Media item = getItem(position);
        holder.text.setText(item.getTitle());

        return view;
    }

    @Override
    public int compare(Media object1, Media object2) {
        return object1.getTitle().compareToIgnoreCase(object2.getTitle());
    }

    public void sort() {
        super.sort(this);
    }

    static class ViewHolder {
        TextView text;
    }
}
